# SGTL - Spectral Graph Theory Library

[![Documentation Status](https://readthedocs.org/projects/sgtl/badge/?version=latest)](https://sgtl.readthedocs.io/en/latest/)

SGTL is a python library of spectral graph theory methods. The library is still very new and so
there are many features and algorithms missing.

You can install the library with `pip install sgtl`.

## Features
* Lightweight and flexible graph object which can be extended as needed.
* Graph matrices including the Laplacian and Normalised Laplacian
* Spectral clustering method
* Generate graphs from the stochastic block model

## Documentation
The full documentation is available [here](https://sgtl.readthedocs.io/en/latest/).

## Contributing
Please feel free to contribute to this project by opening issues, reporting bugs, and submitting
pull requests.

The library is currently maintained by Peter Macgregor (`peter.macgregor@ed.ac.uk`) and you are
welcome to get in touch with any questions.
